@@ -68,6 +68,9 @@
 #'          the viewer pane and not even saved to file. This option is useful when the html output
 #'          should be used in \code{knitr} documents. The html output can be accessed via the return
 #'          value.
+#' @param remove.spaces logical, if \code{TRUE}, leading spaces are removed from all lines in the final string
+#'          that contains the html-data. Use this, if you want to remove parantheses for html-tags. The html-source
+#'          may look less pretty, but it may help when exporting html-tables to office tools.
 #' @return Invisibly returns a \code{\link{structure}} with
 #'          \itemize{
 #'            \item the data frame with the description information (\code{data}),
@@ -128,7 +131,8 @@ sjt.df <- function (df,
                     encoding=NULL,
                     CSS=NULL,
                     useViewer=TRUE,
-                    no.output=FALSE) {
+                    no.output=FALSE,
+                    remove.spaces=TRUE) {
   # check encoding
   encoding <- get.encoding(encoding)
   # -------------------------------------
@@ -358,6 +362,14 @@ sjt.df <- function (df,
   knitr <- gsub(tag.leftalign, css.leftalign, knitr)
   knitr <- gsub(tag.centertalign, css.centertalign, knitr)
   # -------------------------------------
+  # remove spaces?
+  # -------------------------------------
+  if (remove.spaces) {
+    knitr <- sju.rmspc(knitr)
+    toWrite <- sju.rmspc(toWrite)
+    page.content <- sju.rmspc(page.content)
+  }
+  # -------------------------------------
   # check if html-content should be outputted
   # -------------------------------------
   out.html.table(no.output, file, knitr, toWrite, useViewer)
