@@ -103,6 +103,9 @@
 #'          the viewer pane and not even saved to file. This option is useful when the html output
 #'          should be used in \code{knitr} documents. The html output can be accessed via the return
 #'          value.
+#' @param remove.spaces logical, if \code{TRUE}, leading spaces are removed from all lines in the final string
+#'          that contains the html-data. Use this, if you want to remove parantheses for html-tags. The html-source
+#'          may look less pretty, but it may help when exporting html-tables to office tools.
 #' @return Invisibly returns a \code{\link{structure}} with
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
@@ -201,7 +204,8 @@ sjt.frq <- function (data,
                      encoding=NULL,
                      CSS=NULL,
                      useViewer=TRUE,
-                     no.output=FALSE) {
+                     no.output=FALSE,
+                     remove.spaces=TRUE) {
   # -------------------------------------
   # check encoding
   # -------------------------------------
@@ -642,6 +646,14 @@ sjt.frq <- function (data,
   knitr <- gsub(tag.mdrow, css.mdrow, knitr)  
   knitr <- gsub(tag.abstand, css.abstand, knitr)  
   # -------------------------------------
+  # remove spaces?
+  # -------------------------------------
+  if (remove.spaces) {
+    knitr <- sju.rmspc(knitr)
+    toWrite <- sju.rmspc(toWrite)
+    page.content <- sju.rmspc(page.content)
+  }
+  # -------------------------------------
   # check if html-content should be outputted
   # -------------------------------------
   out.html.table(no.output, file, knitr, toWrite, useViewer)
